@@ -12,7 +12,7 @@ our @EXPORT = qw();
 our %EXPORT_TAGS = ( 'all' => [ qw(rur2words) ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 require XSLoader;
 XSLoader::load('Lingua::RU::Money::XS', $VERSION);
@@ -32,7 +32,9 @@ money sum in Russian.
 
 <div id="images">
 	<img src="https://travis-ci.org/igormunkin/Lingua-RU-Money-XS.svg?branch=master" alt="Travis CI Build status (master)"/>
-	<img src='https://coveralls.io/repos/github/igormunkin/Lingua-RU-Money-XS/badge.svg?branch=master' alt='Coverage Status (master)'/>
+	<img src="https://coveralls.io/repos/github/igormunkin/Lingua-RU-Money-XS/badge.svg?branch=master" alt="Coverage Status (master)"/>
+	<img src="https://img.shields.io/cpan/v/Lingua-RU-Money-XS.svg" alt="Cpan version"/>
+	<img src="https://img.shields.io/cpan/l/Lingua-RU-Money-XS.svg" alt="Cpan licence"/>
 </div>
 
 =end HTML
